@@ -1,8 +1,10 @@
 import pytest
 
+from tests.lib import PipTestEnvironment
+
 
 @pytest.mark.network
-def test_timeout(script):
+def test_timeout(script: PipTestEnvironment) -> None:
     result = script.pip(
         "--timeout",
         "0.0001",
