@@ -1,5 +1,6 @@
 import json
 import os
+import pathlib
 import re
 import shutil
 import site
@@ -11,7 +12,18 @@ from contextlib import contextmanager
 from hashlib import sha256
 from io import BytesIO
 from textwrap import dedent
-from typing import Any, Callable, Dict, Iterator, List, Optional, Tuple, Union, cast
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    Iterator,
+    List,
+    Optional,
+    Tuple,
+    Union,
+    cast,
+)
 from zipfile import ZipFile
 
 import pytest
@@ -30,6 +42,14 @@ from tests.lib.path import Path, curdir
 from tests.lib.venv import VirtualEnvironment
 from tests.lib.wheel import make_wheel
 
+if TYPE_CHECKING:
+    # Literal was introduced in Python 3.8.
+    from typing import Literal
+
+    ResolverVariant = Literal["resolvelib", "legacy"]
+else:
+    ResolverVariant = str
+
 DATA_DIR = Path(__file__).parent.parent.joinpath("data").resolve()
 SRC_DIR = Path(__file__).resolve().parent.parent.parent
 
@@ -121,6 +141,7 @@ def make_test_finder(
     allow_all_prereleases: bool = False,
     session: Optional[PipSession] = None,
     target_python: Optional[TargetPython] = None,
+    use_deprecated_html5lib: bool = False,
 ) -> PackageFinder:
     """
     Create a PackageFinder for testing purposes.
@@ -139,6 +160,7 @@ def make_test_finder(
         link_collector=link_collector,
         selection_prefs=selection_prefs,
         target_python=target_python,
+        use_deprecated_html5lib=use_deprecated_html5lib,
     )
 
 
@@ -230,6 +252,8 @@ class TestFailure(AssertionError):
 
 
 class TestPipResult:
+    __test__ = False
+
     def __init__(self, impl: ProcResult, verbose: bool = False) -> None:
         self._impl = impl
 
@@ -246,14 +270,14 @@ class TestPipResult:
     if sys.platform == "win32":
 
         @property
-        def stdout(self):
+        def stdout(self) -> str:
             return self._impl.stdout.replace("\r\n", "\n")
 
         @property
-        def stderr(self):
+        def stderr(self) -> str:
             return self._impl.stderr.replace("\r\n", "\n")
 
-        def __str__(self):
+        def __str__(self) -> str:
             return str(self._impl).replace("\r\n", "\n")
 
     else:
@@ -266,11 +290,11 @@ class TestPipResult:
         self,
         pkg_name: str,
         editable: bool = True,
-        with_files: Optional[List[Path]] = None,
-        without_files: Optional[List[Path]] = None,
+        with_files: Optional[List[str]] = None,
+        without_files: Optional[List[str]] = None,
         without_egg_link: bool = False,
         use_user_site: bool = False,
-        sub_dir: bool = False,
+        sub_dir: Optional[str] = None,
     ) -> None:
         with_files = with_files or []
         without_files = without_files or []
@@ -358,16 +382,16 @@ class TestPipResult:
                     f"Package directory {pkg_dir!r} has unexpected content {f}"
                 )
 
-    def did_create(self, path: Path, message: Optional[str] = None) -> None:
+    def did_create(self, path: str, message: Optional[str] = None) -> None:
         assert str(path) in self.files_created, _one_or_both(message, self)
 
-    def did_not_create(self, path: Path, message: Optional[str] = None) -> None:
+    def did_not_create(self, path: str, message: Optional[str] = None) -> None:
         assert str(path) not in self.files_created, _one_or_both(message, self)
 
-    def did_update(self, path: Path, message: Optional[str] = None) -> None:
+    def did_update(self, path: str, message: Optional[str] = None) -> None:
         assert str(path) in self.files_updated, _one_or_both(message, self)
 
-    def did_not_update(self, path: Path, message: Optional[str] = None) -> None:
+    def did_not_update(self, path: str, message: Optional[str] = None) -> None:
         assert str(path) not in self.files_updated, _one_or_both(message, self)
 
 
@@ -567,7 +591,7 @@ class PipTestEnvironment(TestFileEnvironment):
     def run(
         self,
         *args: str,
-        cwd: Optional[str] = None,
+        cwd: Union[None, str, pathlib.Path] = None,
         allow_stderr_error: Optional[bool] = None,
         allow_stderr_warning: Optional[bool] = None,
         allow_error: bool = False,
@@ -598,7 +622,7 @@ class PipTestEnvironment(TestFileEnvironment):
         cwd = cwd or self.cwd
         if sys.platform == "win32":
             # Partial fix for ScriptTest.run using `shell=True` on Windows.
-            args = [str(a).replace("^", "^^").replace("&", "^&") for a in args]
+            args = tuple(str(a).replace("^", "^^").replace("&", "^&") for a in args)
 
         if allow_error:
             kw["expect_error"] = True
@@ -847,8 +871,8 @@ def _git_commit(
 
 
 def _vcs_add(
-    script: PipTestEnvironment, version_pkg_path: str, vcs: str = "git"
-) -> str:
+    script: PipTestEnvironment, version_pkg_path: Path, vcs: str = "git"
+) -> Path:
     if vcs == "git":
         script.run("git", "init", cwd=version_pkg_path)
         script.run("git", "add", ".", cwd=version_pkg_path)
@@ -874,7 +898,7 @@ def _vcs_add(
         checkout_path: str = script.scratch_path / "pip-test-package"
 
         # svn internally stores windows drives as uppercase; we'll match that.
-        checkout_path = checkout_path.replace("c:", "C:")
+        checkout_path = Path(checkout_path.replace("c:", "C:"))
 
         version_pkg_path = checkout_path
     elif vcs == "bazaar":
@@ -949,7 +973,7 @@ def _create_test_package_with_subdirectory(
 
 def _create_test_package_with_srcdir(
     script: PipTestEnvironment, name: str = "version_pkg", vcs: str = "git"
-) -> str:
+) -> Path:
     script.scratch_path.joinpath(name).mkdir()
     version_pkg_path = script.scratch_path / name
     subdir_path = version_pkg_path.joinpath("subdir")
@@ -979,7 +1003,7 @@ def _create_test_package_with_srcdir(
 
 def _create_test_package(
     script: PipTestEnvironment, name: str = "version_pkg", vcs: str = "git"
-) -> str:
+) -> Path:
     script.scratch_path.joinpath(name).mkdir()
     version_pkg_path = script.scratch_path / name
     _create_main_file(version_pkg_path, name=name, output="0.1")
@@ -1101,9 +1125,9 @@ def create_basic_wheel_for_package(
     name: str,
     version: str,
     depends: Optional[List[str]] = None,
-    extras: Dict[str, str] = None,
+    extras: Dict[str, List[str]] = None,
     requires_python: Optional[str] = None,
-    extra_files: Optional[Dict[str, str]] = None,
+    extra_files: Optional[Dict[str, Union[bytes, str]]] = None,
 ) -> Path:
     if depends is None:
         depends = []
@@ -1161,22 +1185,36 @@ def create_basic_sdist_for_package(
     name: str,
     version: str,
     extra_files: Optional[Dict[str, str]] = None,
+    *,
+    fails_egg_info: bool = False,
+    fails_bdist_wheel: bool = False,
 ) -> Path:
     files = {
-        "setup.py": """
+        "setup.py": f"""\
+            import sys
             from setuptools import find_packages, setup
+
+            fails_bdist_wheel = {fails_bdist_wheel!r}
+            fails_egg_info = {fails_egg_info!r}
+
+            if fails_egg_info and "egg_info" in sys.argv:
+                raise Exception("Simulated failure for generating metadata.")
+
+            if fails_bdist_wheel and "bdist_wheel" in sys.argv:
+                raise Exception("Simulated failure for building a wheel.")
+
             setup(name={name!r}, version={version!r})
         """,
     }
 
     # Some useful shorthands
-    archive_name = "{name}-{version}.tar.gz".format(name=name, version=version)
+    archive_name = f"{name}-{version}.tar.gz"
 
     # Replace key-values with formatted values
     for key, value in list(files.items()):
         del files[key]
         key = key.format(name=name)
-        files[key] = textwrap.dedent(value).format(name=name, version=version).strip()
+        files[key] = textwrap.dedent(value)
 
     # Add new files after formatting
     if extra_files:
