@@ -764,12 +764,12 @@ class TestSubversionArgs(TestCase):
         assert self.call_subprocess_mock.call_args[0][0] == args
 
     def test_obtain(self) -> None:
-        self.svn.obtain(self.dest, hide_url(self.url))
+        self.svn.obtain(self.dest, hide_url(self.url), verbosity=0)
         self.assert_call_args(
             [
                 "svn",
                 "checkout",
-                "-q",
+                "--quiet",
                 "--non-interactive",
                 "--username",
                 "username",
@@ -781,12 +781,12 @@ class TestSubversionArgs(TestCase):
         )
 
     def test_fetch_new(self) -> None:
-        self.svn.fetch_new(self.dest, hide_url(self.url), self.rev_options)
+        self.svn.fetch_new(self.dest, hide_url(self.url), self.rev_options, verbosity=0)
         self.assert_call_args(
             [
                 "svn",
                 "checkout",
-                "-q",
+                "--quiet",
                 "--non-interactive",
                 hide_url("svn+http://username:password@svn.example.com/"),
                 "/tmp/test",
@@ -795,12 +795,12 @@ class TestSubversionArgs(TestCase):
 
     def test_fetch_new_revision(self) -> None:
         rev_options = RevOptions(Subversion, "123")
-        self.svn.fetch_new(self.dest, hide_url(self.url), rev_options)
+        self.svn.fetch_new(self.dest, hide_url(self.url), rev_options, verbosity=0)
         self.assert_call_args(
             [
                 "svn",
                 "checkout",
-                "-q",
+                "--quiet",
                 "--non-interactive",
                 "-r",
                 "123",
